package com.aucma.base.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseSpaceDetailMapper;
import com.aucma.base.domain.BaseSpaceDetail;
import com.aucma.base.service.IBaseSpaceDetailService;

/**
 * 货道明细Service业务层处理
 *
 * @author Yinq
 * @date 2023-10-30
 */
@Service
public class BaseSpaceDetailServiceImpl implements IBaseSpaceDetailService {
    @Autowired
    private BaseSpaceDetailMapper baseSpaceDetailMapper;

    /**
     * 查询货道明细
     *
     * @param objId 货道明细主键
     * @return 货道明细
     */
    @Override
    public BaseSpaceDetail selectBaseSpaceDetailByObjId(Long objId) {
        return baseSpaceDetailMapper.selectBaseSpaceDetailByObjId(objId);
    }

    /**
     * 查询货道明细列表
     *
     * @param baseSpaceDetail 货道明细
     * @return 货道明细
     */
    @Override
    public List<BaseSpaceDetail> selectBaseSpaceDetailList(BaseSpaceDetail baseSpaceDetail) {
        return baseSpaceDetailMapper.selectBaseSpaceDetailList(baseSpaceDetail);
    }

    /**
     * 新增货道明细
     *
     * @param baseSpaceDetail 货道明细
     * @return 结果
     */
    @Override
    public int insertBaseSpaceDetail(BaseSpaceDetail baseSpaceDetail) {
        return baseSpaceDetailMapper.insertBaseSpaceDetail(baseSpaceDetail);
    }

    /**
     * 修改货道明细
     *
     * @param baseSpaceDetail 货道明细
     * @return 结果
     */
    @Override
    public int updateBaseSpaceDetail(BaseSpaceDetail baseSpaceDetail) {
        return baseSpaceDetailMapper.updateBaseSpaceDetail(baseSpaceDetail);
    }

    /**
     * 批量删除货道明细
     *
     * @param objIds 需要删除的货道明细主键
     * @return 结果
     */
    @Override
    public int deleteBaseSpaceDetailByObjIds(Long[] objIds) {
        return baseSpaceDetailMapper.deleteBaseSpaceDetailByObjIds(objIds);
    }

    /**
     * 删除货道明细信息
     *
     * @param objId 货道明细主键
     * @return 结果
     */
    @Override
    public int deleteBaseSpaceDetailByObjId(Long objId) {
        return baseSpaceDetailMapper.deleteBaseSpaceDetailByObjId(objId);
    }
}
